a wip pypi module for giving easy color notifs

NOT ON PYPI YET!

to install while it's not on pypi, git clone, navigate to the root directory and then `pip install .`

but i'd recommend just waiting lol